@@ -15,6 +15,7 @@ import logging
 import uuid
 import zlib
 
+from django.conf import settings
 from django.utils.encoding import smart_str
 
 from sentry.app import env
@@ -91,6 +92,18 @@ class APIRateLimited(APIError):
     msg = 'Creation of this event was denied due to rate limiting.'
 
 
+def get_interface(name):
+    if name not in settings.SENTRY_ALLOWED_INTERFACES:
+        raise ValueError
+
+    try:
+        interface = import_string(name)
+    except Exception:
+        raise ValueError('Unable to load interface: %s' % (name,))
+
+    return interface
+
+
 def client_metadata(client=None, project=None, exception=None, tags=None, extra=None):
     if not extra:
         extra = {}
@@ -322,11 +335,11 @@ def validate_data(project, data, client=None):
             continue
 
         try:
-            interface = import_string(import_path)
-        except (ImportError, AttributeError) as e:
+            interface = get_interface(import_path)
+        except ValueError:
             logger.info(
                 'Invalid unknown attribute: %s', k,
-                **client_metadata(client, project, exception=e))
+                **client_metadata(client, project))
             del data[k]
             continue
 
@@ -363,5 +376,15 @@ def validate_data(project, data, client=None):
     return data
 
 
+def ensure_has_ip(data, ip_address):
+    if data.get('sentry.interfaces.Http', {}).get('env', {}).get('REMOTE_ADDR'):
+        return
+
+    if data.get('sentry.interfaces.User', {}).get('ip_address'):
+        return
+
+    data.setdefault('sentry.interfaces.User', {})['ip_address'] = ip_address
+
+
 def insert_data_to_database(data):
     preprocess_event.delay(data=data)
